Learn R Programming

SuperExactTest (version 1.2.0)

SuperExactTest: SuperExactTest Package

Description

Efficient Test and Visualization of Multi-set Intersections

Arguments

Author

Minghui Wang <minghui.wang@mssm.edu>, Bin Zhang <bin.zhang@mssm.edu>

Details

The main functions that most users may need from this package are supertest and MSET. For a brief introduction of using this package, please see vignette("set_html").

References

Minghui Wang, Yongzhong Zhao, and Bin Zhang (2015). Efficient Test and Visualization of Multi-Set Intersections. Scientific Reports 5: 16923.

See Also

supertest, MSET

Examples

Run this code
if (FALSE) {
#See a brieft instroduction of using this package
vignette("set_html")
}

Run the code above in your browser using DataLab