Learn R Programming

SuperExactTest (version 1.2.0)

deBarcode: Decrypt Barcode

Description

Decrypt barcode information.

Usage

deBarcode(barcode, setnames, collapse=' & ')

Value

A vector.

Arguments

barcode

a vector of character strings, encoding the intersection combination.

setnames

set names.

collapse

an optional character string to separate the results. See paste.

Author

Minghui Wang <minghui.wang@mssm.edu>

Details

barcode are character strings of '0' and '1', indicating absence or presence of each set in a intersection combination.

Examples

Run this code
deBarcode(c('01011','10100'), c('S1','S2','S3','S4','S5'))

Run the code above in your browser using DataLab