Learn R Programming

SuperExactTest (version 1.2.0)

intersect: Set Operations

Description

Performs set union and intersection on multiple input vectors.

Usage

union(x, y, ...)
intersect(x, y, ...)

Value

A vector of the same mode as x or y for intersect, and of a common mode for union.

Arguments

x, y, ...

vectors (of the same mode) containing a sequence of items (conceptually) with no duplicated values.

Author

Minghui Wang <minghui.wang@mssm.edu>, Bin Zhang <bin.zhang@mssm.edu>

Details

These functions extend the the same functions in the base package to handle more than two input vectors.

References

Minghui Wang, Yongzhong Zhao, and Bin Zhang (2015). Efficient Test and Visualization of Multi-Set Intersections. Scientific Reports 5: 16923.

Examples

Run this code
##not run##

Run the code above in your browser using DataLab