powered by
This function outputs summary statistics of a msets object.
# S3 method for msets summary(object, degree=NULL, ...)
A list:
a vector of 0/1 character strings, representing the set composition of each intersection.
a vector of observed intersection size between any combination of sets.
a vector of expected intersection size between any combination of sets if background population size is specified.
set names.
set sizes.
background population size.
upper tail p value for each intersection if background population size n is specified.
a data.frame containing degree, otab, etab, fold change, p value and the overlap elements.
a msets object.
msets
a vector of intersection degrees to pull out.
additional arguments (not implemented).
Minghui Wang <minghui.wang@mssm.edu>, Bin Zhang <bin.zhang@mssm.edu>
Minghui Wang, Yongzhong Zhao, and Bin Zhang (2015). Efficient Test and Visualization of Multi-Set Intersections. Scientific Reports 5: 16923.
if (FALSE) { #set up fake data x=list(S1=letters[1:20], S2=letters[10:26], S3=sample(letters,10), S4=sample(letters,10)) obj=supertest(x,n=26) summary(obj) }
Run the code above in your browser using DataLab